<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Defines restore_cobra_activity_structure_step class
 *
 * @package    mod_cobra
 * @author     Jean-Roch Meurisse
 * @copyright  2016 onwards - Cellule TICE - Unversite de Namur
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

/**
 * Define all the restore steps that will be used by the restore_choice_activity_task
 *
 * @package    mod_cobra
 * @author     Jean-Roch Meurisse
 * @copyright  2016 onwards - Cellule TICE - Universite de Namur
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class restore_cobra_activity_structure_step extends restore_activity_structure_step {

    /**
     * Structure step to restore a cobra activity
     *
     * @return restore_path_element $structure
     */
    protected function define_structure() {
        $paths = [];

        $userinfo = $this->get_setting_value('userinfo');

        $paths[] = new restore_path_element('cobra', '/activity/cobra');
        if ($userinfo) {
            $paths[] = new restore_path_element('clic', '/activity/cobra/clics/clic');
        }
        // Return paths wrapped into standard activity structure.
        return $this->prepare_activity_structure($paths);
    }

    /**
     * Process a cobra restore.
     *
     * @param object $data The data in object form
     * @return void
     */
    protected function process_cobra($data) {
        global $DB;

        $data = (object)$data;
        $data->course = $this->get_courseid();

        $data->timecreated = $this->apply_date_offset($data->timecreated);
        $data->timemodified = $this->apply_date_offset($data->timemodified);

        $newitemid = $DB->insert_record('cobra', $data);
        $this->apply_activity_instance($newitemid);
    }

    /**
     * Process a cobra clic restore.
     *
     * @param object $data The data in object form
     * @return void
     */
    protected function process_clic($data) {
        global $DB;

        $data = (object)$data;
        $data->course = $this->get_courseid();

        $data->cobra = $this->get_new_parentid('cobra');
        $data->userid = $this->get_mappingid('user', $data->userid);

        $DB->insert_record('cobra_click', $data);
        // No need to save this mapping as far as nothing depend on it.
    }

    /**
     * Once the database tables have been fully restored, restore the files
     * @return void
     */
    protected function after_execute() {
        $this->add_related_files('mod_cobra', 'intro', null);
    }
}
